#!/bin/sh

#aclocalincludes="-I /usr/local/share/libtool/libltdl"; 
aclocal $aclocalincludes;
libtoolize -c -f --automake
autoheader; 
autoconf;
automake;

